@@ -30,6 +30,7 @@
 #include <QStatusBar>
 
 #include <kaboutdata.h>
+#include <KIO/ApplicationLauncherJob>
 #include <knotification.h>
 #include <kshell.h>
 #include <kpropertiesdialog.h>
@@ -624,7 +625,6 @@ void CervisiaPart::setupActions()
     //
     // Help Menu
     //
-    action = KStandardAction::helpContents( this, SLOT(slotHelp()), actionCollection());
 
     action  = new QAction(i18n("CVS &Manual"), this);
     actionCollection()->addAction("help_cvs_manual", action);
@@ -1720,17 +1720,12 @@ void CervisiaPart::slotConfigure()
     delete l;
 }
 
-void CervisiaPart::slotHelp()
-{
-    emit setStatusBarText( i18n("Invoking help on Cervisia") );
-    KToolInvocation::startServiceByDesktopName("khelpcenter", QString("help:/cervisia/index.html"));
-}
-
-
 void CervisiaPart::slotCVSInfo()
 {
     emit setStatusBarText( i18n("Invoking help on CVS") );
-    KToolInvocation::startServiceByDesktopName("khelpcenter", QString("info:/cvs/Top"));
+    auto *job = new KIO::ApplicationLauncherJob(KService::serviceByDesktopName("org.kde.khelpcenter"));
+    job->setUrls({QUrl(QStringLiteral("man:/(1)/cvs"))});
+    job->start();
 }
 
 
